@@ -1,24 +1,33 @@
-# Copyright 2012 mdtraj developers
+##############################################################################
+# MDTraj: A Python Library for Loading, Saving, and Manipulating
+#         Molecular Dynamics Trajectories.
+# Copyright 2012-2013 Stanford University and the Authors
 #
-# This file is part of mdtraj
+# Authors: Robert McGibbon
+# Contributors: Kyle A Beauchamp
 #
-# mdtraj is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# MDTraj is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as
+# published by the Free Software Foundation, either version 2.1
+# of the License, or (at your option) any later version.
 #
-# mdtraj is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License along with
-# mdtraj. If not, see http://www.gnu.org/licenses/.
+# You should have received a copy of the GNU Lesser General Public
+# License along with MDTraj. If not, see <http://www.gnu.org/licenses/>.
+##############################################################################
+
 
 ##############################################################################
 # imports
 ##############################################################################
 
+from __future__ import print_function, division
 import os
+import sys
 import functools
 import numpy as np
 from numpy.testing import (assert_allclose, assert_almost_equal,
@@ -30,6 +39,8 @@ from nose.tools import ok_, eq_, raises
 from nose import SkipTest
 from pkg_resources import resource_filename
 
+# py2/3 compatibility
+from mdtraj.utils.six import iteritems
 
 # if the system doesn't have scipy, we'd like
 # this package to still work:
@@ -40,13 +51,20 @@ try:
 except ImportError:
     isspmatrix = lambda x: False
 
+try:
+    # need special logic to check for equality of pandas DataFrames.
+    # but this is only relevant if the user has pandas installed
+    import pandas as pd
+except ImportError:
+    pass
+
 
 __all__ = ['assert_allclose', 'assert_almost_equal', 'assert_approx_equal',
            'assert_array_almost_equal', 'assert_array_almost_equal_nulp',
            'assert_array_equal', 'assert_array_less', 'assert_array_max_ulp',
            'assert_equal', 'assert_raises', 'assert_string_equal', 'assert_warns',
            'get_fn', 'eq', 'assert_dict_equal', 'assert_sparse_matrix_equal',
-           'expected_failure', 'skip', 'ok_', 'eq_', 'raises', 'skipif', 'slow']
+           'expected_failure', 'SkipTest', 'ok_', 'eq_', 'raises', 'skipif', 'slow']
 
 ##############################################################################
 # functions
@@ -72,7 +90,7 @@ def get_fn(name):
     >>> eq(t.n_frames, 20)    # this runs the assert, using the eq() func.
     """
 
-    fn = resource_filename('mdtraj', os.path.join('testing/reference', name))
+    fn = resource_filename('mdtraj', os.path.join('testing', 'reference', name))
 
     if not os.path.exists(fn):
         raise ValueError('Sorry! %s does not exists. If you just '
@@ -131,10 +149,14 @@ def eq(o1, o2, decimal=6, err_msg=''):
         else:
             # compare everything else (ints, bools) for absolute equality
             assert_array_equal(o1, o2, err_msg=err_msg)
+    elif 'pandas' in sys.modules and isinstance(o1, pd.DataFrame):
+        # pandas dataframes are basically like dictionaries of numpy arrayss
+        assert_dict_equal(o1, o2, decimal=decimal)
+
     # probably these are other specialized types
     # that need a special check?
     else:
-        eq_(o1, o2)
+        eq_(o1, o2, msg=err_msg)
 
     return True
 
@@ -146,11 +168,11 @@ def assert_dict_equal(t1, t2, decimal=6):
     """
 
     # make sure the keys are the same
-    eq_(t1.keys(), t2.keys())
+    eq_(list(t1.keys()), list(t2.keys()))
 
-    for key, val in t1.iteritems():
+    for key, val in iteritems(t1):
         # compare numpy arrays using numpy.testing
-        if isinstance(val, np.ndarray):
+        if isinstance(val, np.ndarray) or ('pandas' in sys.modules and isinstance(t1, pd.DataFrame)):
             if val.dtype.kind ==  'f':
                 # compare floats for almost equality
                 assert_array_almost_equal(val, t2[key], decimal)
@@ -194,6 +216,6 @@ def skip(reason):
         @functools.wraps(test)
         def inner(*args, **kwargs):
             raise SkipTest
-            print "After f(*args)"
+            print("After f(*args)")
         return inner
     return wrap
