@@ -1,18 +1,25 @@
-# Copyright 2013-present mdtraj developers
+##############################################################################
+# MDTraj: A Python Library for Loading, Saving, and Manipulating
+#         Molecular Dynamics Trajectories.
+# Copyright 2012-2013 Stanford University and the Authors
 #
-# This file is part of mdtraj
+# Authors: Robert McGibbon
+# Contributors:
 #
-# mdtraj is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
+# MDTraj is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as
+# published by the Free Software Foundation, either version 2.1
+# of the License, or (at your option) any later version.
 #
-# mdtraj is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License along with
-# mdtraj. If not, see http://www.gnu.org/licenses/.
+# You should have received a copy of the GNU Lesser General Public
+# License along with MDTraj. If not, see <http://www.gnu.org/licenses/>.
+##############################################################################
+
 
 """
 Code to test the mdconvert script. These tests take about two minutes to run.
@@ -32,6 +39,7 @@ import shutil
 import numpy as np
 
 import mdtraj as md
+from mdtraj import element
 from mdtraj.utils import import_
 from mdtraj.testing import skipif, get_fn, eq, slow
 
@@ -60,15 +68,15 @@ def teardown_module(module):
 def setup_module():
     global TRAJ
 
-    xyz = np.arange(150, dtype=np.float32).reshape(10,5,3)
+    xyz = np.around(np.random.randn(10, 5, 3).astype(np.float32), 2)
     topology = md.Topology()
     chain = topology.add_chain()
     residue = topology.add_residue('ALA', chain)
-    topology.add_atom('CA', md.pdb.element.carbon, residue)
-    topology.add_atom('HG1', md.pdb.element.hydrogen, residue)
-    topology.add_atom('SG', md.pdb.element.sulfur, residue)
-    topology.add_atom('OD1', md.pdb.element.oxygen, residue)
-    topology.add_atom('NE', md.pdb.element.nitrogen, residue)
+    topology.add_atom('CA', element.carbon, residue)
+    topology.add_atom('HG1', element.hydrogen, residue)
+    topology.add_atom('SG', element.sulfur, residue)
+    topology.add_atom('OD1', element.oxygen, residue)
+    topology.add_atom('NE', element.nitrogen, residue)
 
     time = np.arange(10)**2
     unitcell_lengths = np.array([[1.1,1.2,1.3]] * 10)
@@ -130,7 +138,8 @@ def test_mdconvert_0():
     np.savetxt(atom_indices_fn, atom_indices, fmt='%d')
 
     fns = ['traj.xtc', 'traj.dcd', 'traj.binpos', 'traj.trr', 'traj.nc',
-           'traj.pdb', 'traj.h5']
+           'traj.pdb', 'traj.h5', 'traj.lh5', 'traj.netcdf']
+    # fns = ['traj.lh5', 'traj.netcdf']
 
     for fn in fns:
         path = os.path.join(staging_dir, fn)
@@ -140,7 +149,7 @@ def test_mdconvert_0():
             ext1, ext2 = [os.path.splitext(f)[1] for f in [fn, fn2]]
 
             command1 = ['mdconvert', path, '-o', fn2, '-c 6']
-            if ext2 in ['.pdb', '.h5']:
+            if ext2 in ['.pdb', '.h5', '.lh5']:
                 # if we're saving a pdb or h5, we need to give it a topology too
                 command1 += ['-t', topology_fn]
 
@@ -167,7 +176,7 @@ def test_mdconvert_0():
             # ensure that the xyz coordinates are preserved by a trip
             # from python -> save in format X -> mdconvert to format Y -> python
             load_kwargs_check1, load_kwargs_check2 = {}, {}
-            if ext2 not in ['.pdb', '.h5']:
+            if ext2 not in ['.pdb', '.h5', '.lh5']:
                 load_kwargs_check1['top'] = TRAJ.topology
                 load_kwargs_check2['top'] = TRAJ.topology.subset(atom_indices)
 
@@ -176,11 +185,15 @@ def test_mdconvert_0():
                 out2 = md.load(os.path.join(output_dir, 'subset.' + fn2), **load_kwargs_check2)
                 out3 = md.load(os.path.join(output_dir, 'stride.' + fn2), **load_kwargs_check1)
 
-                eq(out1.xyz, TRAJ.xyz)
-                eq(out2.xyz, TRAJ.xyz[:, atom_indices])
-                eq(out3.xyz, TRAJ.xyz[::3])
+                if ext1 in ['.lh5'] or ext2 in ['.lh5']:
+                    decimal = 3
+                else:
+                    decimal = 6
+                eq(out1.xyz, TRAJ.xyz, decimal=decimal)
+                eq(out2.xyz, TRAJ.xyz[:, atom_indices], decimal=decimal)
+                eq(out3.xyz, TRAJ.xyz[::3], decimal=decimal)
 
-                if ext1 != '.binpos' and ext2 != '.binpos':
+                if ext1 not in ['.binpos', '.lh5'] and ext2 not in ['.binpos', '.lh5']:
                     # binpos doesn't save unitcell information
                     eq(out1.unitcell_vectors, TRAJ.unitcell_vectors, decimal=2)
                     eq(out2.unitcell_vectors, TRAJ.unitcell_vectors, decimal=2)
@@ -192,7 +205,7 @@ def test_mdconvert_0():
                     eq(out2.time, TRAJ.time)
                     eq(out3.time, TRAJ.time[::3])
 
-                if ext2 in ['.pdb', '.h5']:
+                if ext2 in ['.pdb', '.h5', '.lh5']:
                     # these formats contain a topology in the file that was
                     # read from disk
                     eq(out1.topology, TRAJ.topology)
@@ -203,9 +216,23 @@ def test_mdconvert_0():
             yield check
 
             if not DEBUG_MODE:
-                env.run('rm', '-f', fn2)
-                env.run('rm', '-f', 'subset.' + fn2)
-                env.run('rm', '-f', 'stride.' + fn2)
+                os.unlink(os.path.join(output_dir, fn2))
+                os.unlink(os.path.join(output_dir, 'subset.' + fn2))
+                os.unlink(os.path.join(output_dir, 'stride.' + fn2))
 
         if not DEBUG_MODE:
             os.unlink(path)
+
+@slow
+@skipif(not HAVE_SCRIPTTEST)
+def test_mdconvert_1():
+    env = scripttest.TestFileEnvironment(output_dir)
+    command = ['mdconvert', get_fn('alanine-dipeptide-explicit.binpos'), '--top',
+                get_fn('alanine-dipeptide-explicit.prmtop'), '-o', 'out.dcd']
+    env.run(*command, expect_stderr=True)
+    t = md.load(os.path.join(output_dir, 'out.dcd'), top=get_fn('alanine-dipeptide-explicit.prmtop'))
+    t2 = md.load(get_fn('alanine-dipeptide-explicit.binpos'), top=get_fn('alanine-dipeptide-explicit.prmtop'))
+
+    eq(t.xyz, t2.xyz)
+    eq(t.topology, t2.topology)
+
